# Read-map

### Version 0.5.1

Feature freeze. Fixes and testing.

- [ ] Review todos
- [x] Performance tests
- [x] Scaling test
- [x] Unit tests
- [x] Integration tests
- [x] Project management: Feature list for contributors
- [x] UX: Simplify selecting event for debugging
- [x] Console log


### Version 0.6.0

#### Features:

- [ ] Proof of concept for dynamic front-end loading
- [x] Workflow profiling
- [ ] Every time segments raises error log that error to tracardi-console-log index - so we can see that this segment is not right. 
- [ ] Standard Error Reporting, showing console-log ang logging to stdout
- [ ] Tracardi user profile domain object
- [ ] Forgot password functionality
- [ ] Workflow parameters – Workflow has its own parameters that can be copied to action parameters. This allows for making workflow as a closed solution with own configuration. With this feature a ready to use workflows could be defined. 
- [x] Reading data from external sources – use source configuration to fetch data
- [ ] If Action – Should use plain/text editor not application/json
- [ ] Search
- [ ] Full profile, event, and sessions details page

- [ ] GraphQL Endpoint for profile fetching. ???
- [x] Profiler as part of debugger
- [x] Refactor menu to take less space
- [ ] Finish manual
- [x] Error log - console log for developers
- [x] Editable name for node in flow
- [ ] Scheduler - tasks with intervals
- [x] Tasker

### Version 0.7.0

- [ ] Setting user and password from interface (user profile), use keycloak
- [ ] text/plain - editor in config